# TropiPy
TropiPay SDK Python

## Install
- pip install -r requirements.txt
- pip show requests
- pip list -v

## Test
- python -m unittest                        # One command to run them all
- python -m unittest tests/test_login.py    # Selective run some test suite
